<?php

class BillController extends Controller {

    public function actionCheckin() {
        $model = new Bill();
        if (isset($_POST['Bill'])) {
            $model->attributes = $_POST['Bill'];

            $transaction = Yii::app()->db->beginTransaction();
            try {
                if ($model->save()) {
                    $transaction->commit();
                    $this->success(array('OK'));
                } else {
                    $this->expandErrors($model);
                }
            } catch (Exception $ex) {
                $transaction->rollback();
                $this->error($ex->getMessage());
            }
        } else {
            $this->render('checkin', array('model' => $model));
        }
    }

    public function actionCheckout($hostid) {
        $model = Bill::model()->getBillByHostID($hostid);
        if ($model != null) {
            $transaction = Yii::app()->db->beginTransaction();
            try {
                $model->spBill_Close($model->billno);
                $transaction->commit();
                $this->success(array('status' => 'OK'));
            } catch (Exception $ex) {
                $transaction->rollback();
                $this->error($ex->getMessage());
            }
        } else {
            $this->error('The requested page does not exist.');
        }
    }

    public function loadModel($id) {
        $model = Bill::model()->findByPk($id);
        if ($model === null)
            $this->error('The requested page does not exist.');

        return $model;
    }

    public function actionView($id) {
        $model = $this->loadModel($id);

        $this->success($model);
    }

    public function actionCancel($hostid) {
        $model = Bill::model()->getBillByHostID($hostid);
        if ($model != null) {
            $transaction = Yii::app()->db->beginTransaction();
            try {
                $model->spBill_Cancel($model->billno);
                $transaction->commit();
                $this->success(array('status' => 'OK'));
            } catch (Exception $ex) {
                $transaction->rollback();
                $this->error($ex->getMessage());
            }
        } else {
            $this->error('The requested page does not exist.');
        }
    }

    public function actionMove($billno, $oldhostid, $newhostid) {
        $model = $this->loadModel($billno);
        $transaction = Yii::app()->db->beginTransaction();
        try {
            $model->spBill_Move($oldhostid, $newhostid);
            $transaction->commit();
            $this->success(array('status' => 'OK'));
        } catch (Exception $ex) {
            $transaction->rollback();
            $this->error($ex->getMessage());
        }
    }

    public function actionPrint($billno) {
        $model = Bill::model()->findByPk($billno);
        if ($model != null) {
            $detail = array();
            $subtotal = 0;
            $discamt = 0;
            $taxamt = 0;
            $total = 0;

            $sales = $model->sales;
            $sos = $model->sos;
            if (count($sales) > 0) {
                foreach ($sales as $sale) {
                    $saleds = $sale->saleds;
                    foreach ($saleds as $saled) {
                        $saled_temp = array();

                        $saled_temp['no'] = $saled->saledno;
                        $saled_temp['itemid'] = $saled->itemid;
                        $saled_temp['itemdesc'] = $saled->itemdesc;
                        $saled_temp['qty'] = $saled->qty;
                        $saled_temp['unit'] = $saled->unit;
                        $saled_temp['listprice'] = $saled->listprice;
                        $saled_temp['discamt'] = $saled->discamt;
                        $saled_temp['taxamt'] = $saled->taxamt;
                        $saled_temp['subtotal'] = $saled->subtotal;

                        $detail[] = $saled_temp;
                    }

                    $subtotal += $sale->subtotal;
                    $discamt += $sale->discamt;
                    $taxamt += $sale->taxamt;
                    $total += $sale->total;
                }
            } else {
                foreach ($sos as $so) {
                    $sods = $so->sods;
                    foreach ($sods as $sod) {
                        $sod_temp = array();
                        if (!$sod->iscancel) {
                            $sod_temp['no'] = $sod->sodno;
                            $sod_temp['itemid'] = $sod->itemid;
                            $sod_temp['itemdesc'] = $sod->itemdesc;
                            $sod_temp['qty'] = $sod->qty;
                            $sod_temp['unit'] = $sod->unit;
                            $sod_temp['listprice'] = $sod->listprice;
                            $sod_temp['discamt'] = $sod->discamt;
                            $sod_temp['taxamt'] = $sod->taxamt;
                            $sod_temp['subtotal'] = $sod->subtotal;

                            $detail[] = $sod_temp;

                            $subtotal += $sod->subtotal;
//                            $discamt += $sod->discamt;
                            $taxamt += $sod->totaltaxamt;
                        }
                    }
                }

                $total = $subtotal - $discamt + $taxamt;
            }
            
            //add service charge
            if (Reg::model()->getRegVal("SERVCHAR_ENB")) {
                $itemid = Reg::model()->getRegVal("SERVCHAR_ITEM");
                $persen = Reg::model()->getRegVal("SERVCHAR_EXP");
                $service_charge = 0;
                if ($itemid != null && strlen($itemid) > 0 && $persen != null && strlen($persen) > 0) {
                    $service_charge_temp = array();
                    
                    $item = Item::model()->findByPk($itemid);
                    $service_charge = BHelp::EvalTaxExp($subtotal, $persen);
                    
                    $taxid = Item::model()->getSaleTaxId($itemid);
                    $taxexp = Tax::model()->getTaxExp($taxid);
                    $service_charge_taxamt = BHelp::EvalTaxExp($service_charge, $taxexp);

                    $service_charge_temp['no'] = 1;
                    $service_charge_temp['itemid'] = $itemid;
                    $service_charge_temp['itemdesc'] = $item->itemdesc;
                    $service_charge_temp['qty'] = 1;
                    $service_charge_temp['unit'] = $item->unit1;
                    $service_charge_temp['listprice'] = $service_charge;
                    $service_charge_temp['discamt'] = 0;
                    $service_charge_temp['taxamt'] = $service_charge_taxamt;
                    $service_charge_temp['subtotal'] = $service_charge;

                    $detail[] = $service_charge_temp;
                    
                    $subtotal += $service_charge;
//                    $discamt += 0;
                    $taxamt += $service_charge_taxamt;
                    $total += $service_charge + $service_charge_taxamt;
                }
            }

            $data = array(
                'detail' => $detail,
                'subtotal' => $subtotal,
                'discamt' => $discamt,
                'taxamt' => $taxamt,
                'total' => $total,
            );

            $this->success($data);
        } else {
            $this->error('The requested page does not exist.');
        }
    }

}
