<?php

/**
 * This is the model class for table "bp".
 *
 * The followings are the available columns in table 'bp':
 * @property string $bpid
 * @property string $collectorid
 * @property string $taxtype
 * @property string $purctopid
 * @property string $bpstatusid
 * @property string $saletaxid
 * @property string $canvasid
 * @property string $srepid
 * @property string $indid
 * @property string $saletopid
 * @property string $areaid
 * @property string $purctaxid
 * @property string $prclvlid
 * @property string $bpgrpid
 * @property string $crcid
 * @property string $bpname
 * @property string $anniversary
 * @property boolean $purcistaxed
 * @property boolean $purctaxinc
 * @property boolean $saleistaxed
 * @property boolean $saletaxinc
 * @property string $taxregno
 * @property string $vatregno
 * @property string $vatregdate
 * @property string $bankname
 * @property string $bankaccno
 * @property string $bankaccname
 * @property string $email
 * @property string $website
 * @property string $bpnote
 * @property boolean $active
 * @property boolean $_xt
 *
 * The followings are the available model relations:
 * @property Addr[] $addrs
 * @property Bill[] $bills
 * @property Bpa[] $bpas
 * @property Bplog[] $bplogs
 * @property Casha[] $cashas
 * @property Bpsched[] $bpscheds
 * @property Crc[] $crcs
 * @property Bns[] $bns
 * @property Bns[] $bns1
 * @property Bptype[] $bptypes
 * @property Bpcbal[] $bpcbals
 * @property Bpdbal[] $bpdbals
 * @property Top $purctop
 * @property Top $saletop
 * @property Tax $purctax
 * @property Tax $saletax
 * @property Area $area
 * @property Bpgrp $bpgrp
 * @property Bpstatus $bpstatus
 * @property Canvas $canvas
 * @property Collector $collector
 * @property Crc $crc
 * @property Ind $ind
 * @property Prclvl $prclvl
 * @property Srep $srep
 * @property Taxtype $taxtype0
 * @property Cont[] $conts
 * @property Cons[] $cons
 * @property Cbg[] $cbgs
 * @property Cbg[] $cbgs1
 * @property Cret[] $crets
 * @property Dp[] $dps
 * @property Deo[] $deos
 * @property Deo[] $deos1
 * @property Hostwo[] $hostwos
 * @property Mfg[] $mfgs
 * @property Prcv[] $prcvs
 * @property Pprc[] $pprcs
 * @property Pprc[] $pprcs1
 * @property Po[] $pos
 * @property Rcv[] $rcvs
 * @property Purc[] $purcs
 * @property Prj[] $prjs
 * @property Sadj[] $sadjs
 * @property Sq[] $sqs
 * @property Sret[] $srets
 * @property Stocka[] $stockas
 * @property Pay[] $pays
 * @property So[] $sos
 * @property So[] $sos1
 * @property Cadj[] $cadjs
 * @property Fcn[] $fcns
 * @property Sale[] $sales
 * @property Sale[] $sales1
 * @property Deli[] $delis
 * @property Deli[] $delis1
 * @property Pret[] $prets
 * @property Item[] $items
 * @property Wo[] $wos
 */
class Bp extends CActiveRecord {

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Bp the static model class
     */
    public static function model($className=__CLASS__) {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'bp';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('bpid', 'required'),
            array('bpid', 'length', 'max' => 15),
            array('collectorid, srepid, areaid, bpgrpid', 'length', 'max' => 10),
            array('taxtype, purctopid, saletaxid, canvasid, indid, saletopid, purctaxid, crcid', 'length', 'max' => 5),
            array('bpstatusid', 'length', 'max' => 2),
            array('prclvlid', 'length', 'max' => 3),
            array('bpname, taxregno, vatregno, bankname, email, website', 'length', 'max' => 50),
            array('bankaccno, bankaccname', 'length', 'max' => 30),
            array('bpnote', 'length', 'max' => 255),
            array('anniversary, purcistaxed, purctaxinc, saleistaxed, saletaxinc, vatregdate, active, _xt', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('bpid, collectorid, taxtype, purctopid, bpstatusid, saletaxid, canvasid, srepid, indid, saletopid, areaid, purctaxid, prclvlid, bpgrpid, crcid, bpname, anniversary, purcistaxed, purctaxinc, saleistaxed, saletaxinc, taxregno, vatregno, vatregdate, bankname, bankaccno, bankaccname, email, website, bpnote, active, _xt', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'addrs' => array(self::HAS_MANY, 'Addr', 'bpid'),
            'bills' => array(self::HAS_MANY, 'Bill', 'bpid'),
            'bpas' => array(self::HAS_MANY, 'Bpa', 'bpid'),
            'bplogs' => array(self::HAS_MANY, 'Bplog', 'bpid'),
            'cashas' => array(self::HAS_MANY, 'Casha', 'bpid'),
            'bpscheds' => array(self::HAS_MANY, 'Bpsched', 'bpid'),
            'crcs' => array(self::MANY_MANY, 'Crc', 'bpacc(bpid, crcid)'),
            'bns' => array(self::HAS_MANY, 'Bns', 'custid'),
            'bns1' => array(self::HAS_MANY, 'Bns', 'vendorid'),
            'bptypes' => array(self::MANY_MANY, 'Bptype', 'bpbptype(bpid, bptype)'),
            'bpcbals' => array(self::HAS_MANY, 'Bpcbal', 'bpid'),
            'bpdbals' => array(self::HAS_MANY, 'Bpdbal', 'bpid'),
            'purctop' => array(self::BELONGS_TO, 'Top', 'purctopid'),
            'saletop' => array(self::BELONGS_TO, 'Top', 'saletopid'),
            'purctax' => array(self::BELONGS_TO, 'Tax', 'purctaxid'),
            'saletax' => array(self::BELONGS_TO, 'Tax', 'saletaxid'),
            'area' => array(self::BELONGS_TO, 'Area', 'areaid'),
            'bpgrp' => array(self::BELONGS_TO, 'Bpgrp', 'bpgrpid'),
            'bpstatus' => array(self::BELONGS_TO, 'Bpstatus', 'bpstatusid'),
            'canvas' => array(self::BELONGS_TO, 'Canvas', 'canvasid'),
            'collector' => array(self::BELONGS_TO, 'Collector', 'collectorid'),
            'crc' => array(self::BELONGS_TO, 'Crc', 'crcid'),
            'ind' => array(self::BELONGS_TO, 'Ind', 'indid'),
            'prclvl' => array(self::BELONGS_TO, 'Prclvl', 'prclvlid'),
            'srep' => array(self::BELONGS_TO, 'Srep', 'srepid'),
            'taxtype0' => array(self::BELONGS_TO, 'Taxtype', 'taxtype'),
            'conts' => array(self::HAS_MANY, 'Cont', 'bpid'),
            'cons' => array(self::HAS_MANY, 'Cons', 'custid'),
            'cbgs' => array(self::HAS_MANY, 'Cbg', 'frombpid'),
            'cbgs1' => array(self::HAS_MANY, 'Cbg', 'tobpid'),
            'crets' => array(self::HAS_MANY, 'Cret', 'custid'),
            'dps' => array(self::HAS_MANY, 'Dp', 'bpid'),
            'deos' => array(self::HAS_MANY, 'Deo', 'refrid'),
            'deos1' => array(self::HAS_MANY, 'Deo', 'custid'),
            'hostwos' => array(self::HAS_MANY, 'Hostwo', 'bpid'),
            'mfgs' => array(self::HAS_MANY, 'Mfg', 'custid'),
            'prcvs' => array(self::HAS_MANY, 'Prcv', 'vendorid'),
            'pprcs' => array(self::HAS_MANY, 'Pprc', 'vendorid'),
            'pprcs1' => array(self::HAS_MANY, 'Pprc', 'custid'),
            'pos' => array(self::HAS_MANY, 'Po', 'vendorid'),
            'rcvs' => array(self::HAS_MANY, 'Rcv', 'bpid'),
            'purcs' => array(self::HAS_MANY, 'Purc', 'vendorid'),
            'prjs' => array(self::HAS_MANY, 'Prj', 'bpid'),
            'sadjs' => array(self::HAS_MANY, 'Sadj', 'bpid'),
            'sqs' => array(self::HAS_MANY, 'Sq', 'bpid'),
            'srets' => array(self::HAS_MANY, 'Sret', 'custid'),
            'stockas' => array(self::HAS_MANY, 'Stocka', 'bpid'),
            'pays' => array(self::HAS_MANY, 'Pay', 'bpid'),
            'sos' => array(self::HAS_MANY, 'So', 'refrid'),
            'sos1' => array(self::HAS_MANY, 'So', 'custid'),
            'cadjs' => array(self::HAS_MANY, 'Cadj', 'bpid'),
            'fcns' => array(self::HAS_MANY, 'Fcn', 'bpid'),
            'sales' => array(self::HAS_MANY, 'Sale', 'custid'),
            'sales1' => array(self::HAS_MANY, 'Sale', 'refrid'),
            'delis' => array(self::HAS_MANY, 'Deli', 'refrid'),
            'delis1' => array(self::HAS_MANY, 'Deli', 'custid'),
            'prets' => array(self::HAS_MANY, 'Pret', 'vendorid'),
            'items' => array(self::HAS_MANY, 'Item', 'vendorid'),
            'wos' => array(self::HAS_MANY, 'Wo', 'custid'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'bpid' => Yii::t('bp', 'bpid'),
            'collectorid' => Yii::t('bp', 'collectorid'),
            'taxtype' => Yii::t('bp', 'taxtype'),
            'purctopid' => Yii::t('bp', 'purctopid'),
            'bpstatusid' => Yii::t('bp', 'bpstatusid'),
            'saletaxid' => Yii::t('bp', 'saletaxid'),
            'canvasid' => Yii::t('bp', 'canvasid'),
            'srepid' => Yii::t('bp', 'srepid'),
            'indid' => Yii::t('bp', 'indid'),
            'saletopid' => Yii::t('bp', 'saletopid'),
            'areaid' => Yii::t('bp', 'areaid'),
            'purctaxid' => Yii::t('bp', 'purctaxid'),
            'prclvlid' => Yii::t('bp', 'prclvlid'),
            'bpgrpid' => Yii::t('bp', 'bpgrpid'),
            'crcid' => Yii::t('bp', 'crcid'),
            'bpname' => Yii::t('bp', 'bpname'),
            'anniversary' => Yii::t('bp', 'anniversary'),
            'purcistaxed' => Yii::t('bp', 'purcistaxed'),
            'purctaxinc' => Yii::t('bp', 'purctaxinc'),
            'saleistaxed' => Yii::t('bp', 'saleistaxed'),
            'saletaxinc' => Yii::t('bp', 'saletaxinc'),
            'taxregno' => Yii::t('bp', 'taxregno'),
            'vatregno' => Yii::t('bp', 'vatregno'),
            'vatregdate' => Yii::t('bp', 'vatregdate'),
            'bankname' => Yii::t('bp', 'bankname'),
            'bankaccno' => Yii::t('bp', 'bankaccno'),
            'bankaccname' => Yii::t('bp', 'bankaccname'),
            'email' => Yii::t('bp', 'email'),
            'website' => Yii::t('bp', 'website'),
            'bpnote' => Yii::t('bp', 'bpnote'),
            'active' => Yii::t('bp', 'active'),
            '_xt' => Yii::t('bp', '_xt'),
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search() {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('bpid', $this->bpid, true);
        $criteria->compare('collectorid', $this->collectorid, true);
        $criteria->compare('taxtype', $this->taxtype, true);
        $criteria->compare('purctopid', $this->purctopid, true);
        $criteria->compare('bpstatusid', $this->bpstatusid, true);
        $criteria->compare('saletaxid', $this->saletaxid, true);
        $criteria->compare('canvasid', $this->canvasid, true);
        $criteria->compare('srepid', $this->srepid, true);
        $criteria->compare('indid', $this->indid, true);
        $criteria->compare('saletopid', $this->saletopid, true);
        $criteria->compare('areaid', $this->areaid, true);
        $criteria->compare('purctaxid', $this->purctaxid, true);
        $criteria->compare('prclvlid', $this->prclvlid, true);
        $criteria->compare('bpgrpid', $this->bpgrpid, true);
        $criteria->compare('crcid', $this->crcid, true);
        $criteria->compare('bpname', $this->bpname, true);
        $criteria->compare('anniversary', $this->anniversary, true);
        $criteria->compare('purcistaxed', $this->purcistaxed);
        $criteria->compare('purctaxinc', $this->purctaxinc);
        $criteria->compare('saleistaxed', $this->saleistaxed);
        $criteria->compare('saletaxinc', $this->saletaxinc);
        $criteria->compare('taxregno', $this->taxregno, true);
        $criteria->compare('vatregno', $this->vatregno, true);
        $criteria->compare('vatregdate', $this->vatregdate, true);
        $criteria->compare('bankname', $this->bankname, true);
        $criteria->compare('bankaccno', $this->bankaccno, true);
        $criteria->compare('bankaccname', $this->bankaccname, true);
        $criteria->compare('email', $this->email, true);
        $criteria->compare('website', $this->website, true);
        $criteria->compare('bpnote', $this->bpnote, true);
        $criteria->compare('active', $this->active);
        $criteria->compare('_xt', $this->_xt);

        return new CActiveDataProvider($this, array(
                    'criteria' => $criteria,
                ));
    }

    public function getSaleIsTaxed($bpid) {
        $model = self::model()->findByPk($bpid);
        if ($model != null) {
            return $model->saleistaxed;
        } else {
            return null;
        }
    }
    
    public function getPrcLvlId($bpid) {
        $model = self::model()->findByPk($bpid);
        if ($model != null) {
            return $model->prclvlid;
        } else {
            return null;
        }
    }
    
    public function getSaleTaxeId($bpid) {
        $model = self::model()->findByPk($bpid);
        if ($model != null) {
            return $model->saletaxid;
        } else {
            return null;
        }
    }
    
    public function getBPGrpId($bpid) {
        $model = self::model()->findByPk($bpid);
        if ($model != null) {
            return $model->bpgrpid;
        } else {
            return null;
        }
    }

}